==> python_uv-0.0.31.tar.gz: python_uv-0.0.31/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

## 0.0.31 - 2024-10-27

### 🚀 Features

- Package python with uv

### 🚜 Refactor

- Remove src/* -> src/python_uv/* as a package

### ⚙️ Miscellaneous Tasks

- Vscode import plugin update

## 0.0.30 - 2024-10-26

### ⚙️ Miscellaneous Tasks

- *(Merge)* Pull request #2 from Atticuszz:test-PR in #2 by @Atticuszz

## 0.0.29 - 2024-10-26

### ⚙️ Miscellaneous Tasks

- Remove commit_preprocessors on issue number by @Atticuszz

## 0.0.28 - 2024-10-26

### 🚀 Features

- *(CHANGELOG)* Add pr number and author name after commit message via set remote repo for git-cliff by @Atticuszz

## 0.0.27 - 2024-10-26

### 🐛 Bug Fixes

- Exclude hidden folder and file in pre-commit by @Atticuszz

### 📚 Documentation

- *(VCS)* Update CHANGELOG.md with link by @Atticuszz

### ⚙️ Miscellaneous Tasks

- *(VCS)* Add bump version shell by @Atticuszz
- Fix typo in README.md by @Atticuszz
- Clean config for git-cliff by @Atticuszz
- *(CHANGELOG)* Remove "[]" in version number by @Atticuszz
- *(CHANGELOG)* Remove "[]" in version number and filter duplicate commit message by @Atticuszz
- Remove duplicate config on git-cliff by @Atticuszz

## 0.0.23 - 2024-10-26

### 🐛 Bug Fixes

- *(CI)* Body->body_path context in release ci by @Atticuszz

## 0.0.22 - 2024-10-26

### 🐛 Bug Fixes

- *(CI)* Release without CHANGES.md by @Atticuszz

## 0.0.21 - 2024-10-26

### 🐛 Bug Fixes

- *(CI)* Release ci can not read latest changes by @Atticuszz

## 0.0.20 - 2024-10-26

### ⚙️ Miscellaneous Tasks

- Add notes for tool.bumpversion.allow_dirty=true by @Atticuszz

## 0.0.19 - 2024-10-25

### 🐛 Bug Fixes

- Pyproject.toml by @Atticuszz

## 0.0.18 - 2024-10-25

### 🐛 Bug Fixes

- Pyproject.toml version by @Atticuszz

## 0.0.17 - 2024-10-25

### 🐛 Bug Fixes

- Bumpverison files search name by @Atticuszz
- CHANGELOG.md bump replace result by @Atticuszz

## 0.0.16 - 2024-10-25

### 🐛 Bug Fixes

- Version in pyproject.toml by @Atticuszz

### ⚙️ Miscellaneous Tasks

- Add bump version to CHANGELOG.md by @Atticuszz

## 0.0.15 - 2024-10-25

### 🐛 Bug Fixes

- Bumpversion files by @Atticuszz

## 0.0.14 - 2024-10-25

### 🐛 Bug Fixes

- Bumpversion.files by @Atticuszz

## 0.0.13 - 2024-10-25

### ⚙️ Miscellaneous Tasks

- Add bumpversion files by @Atticuszz

## 0.0.12 - 2024-10-25

### 🐛 Bug Fixes

- Test bump by @Atticuszz

## 0.0.11 - 2024-10-25

### 🐛 Bug Fixes

- Test by @Atticuszz

## 0.0.10 - 2024-10-25

### 🐛 Bug Fixes

- *(vcs)* Remove changelog header by @Atticuszz
- *(CI)* Release-note is not total CHANGELOG.md by @Atticuszz
- *(CI)* Release only with tags branches by @Atticuszz
- *(CI)* Release on tags branches by @Atticuszz
- Test git-changelog by @Atticuszz
- *(dep)* Remove git-changelog by @Atticuszz

### ⚙️ Miscellaneous Tasks

- Add git-cliff by @Atticuszz
- Run pre-commit by @Atticuszz
- *(dep)* Update changelog by @Atticuszz
- Update pyproject.toml by @Atticuszz
- *(CI)* Remove release condition by @Atticuszz

### Bump

- *(CI)* Fix release body path file by @Atticuszz
- Fix ci if release conditions by @Atticuszz
- 0.0.9->0.0.10 by @Atticuszz

## 0.0.9 - 2024-10-23

### 🐛 Bug Fixes

- *(pyproject.toml)* Bug show by @Atticuszz
- *(pyproject.toml)* Add local dev commitizen by @Atticuszz

### 📚 Documentation

- Test  docs by @Atticuszz

### ⚡ Performance

- Test pre by @Atticuszz

### Bump

- Version 0.0.8 → 0.0.9 by @Atticuszz

## 0.0.8 - 2024-10-23

### 🐛 Bug Fixes

- *(.vscode)* Enable python package import plugin by @Atticuszz

### Bump

- Version 0.0.7 → 0.0.8 by @Atticuszz

## 0.0.7 - 2024-10-22

### 🐛 Bug Fixes

- *(main.yml)* Release condition is the commit message with bump: by @Atticuszz

### Bump

- Version 0.0.6 → 0.0.7 by @Atticuszz

## 0.0.6 - 2024-10-22

### 🐛 Bug Fixes

- *(main.ci)* Failed to get tag to release by @Atticuszz

### 📚 Documentation

- Update obsidian plugins by @Atticuszz

### Bump

- Version 0.0.5 → 0.0.6 by @Atticuszz

## 0.0.5 - 2024-10-20

### 🐛 Bug Fixes

- *(pyproject.toml)* Test fix by @Atticuszz
- *(pyproject.toml)* Add all change_type to changelog_pattern by @Atticuszz
- *(pyproject.toml)* Change_type_map by @Atticuszz
- Pyproject.toml by @Atticuszz

### 📚 Documentation

- *(mkdocs.yml)* Update site name and copyright by @Atticuszz

### Bump

- Version 0.0.4 → 0.0.5 by @Atticuszz

## 0.0.4 - 2024-10-19

### 🐛 Bug Fixes

- *(.obsidian)* Remove obsidian-git plugin by @Atticuszz

### 📚 Documentation

- *(docs/)* Remove git plugin of .obsidian and update all by @Atticuszz
- *(README.md)* Update by @Atticuszz

### 🎨 Styling

- *(.obsidian)* Pre-commit run by @Atticuszz

### ⚙️ Miscellaneous Tasks

- *(docs.yml,-main.yml)* 1. update ci uses as @main instead of @v_number, 2. add bump and release by @Atticuszz

### Bump

- Version 0.0.3 → 0.0.4 by @Atticuszz

## 0.0.3 - 2024-10-19

### 🐛 Bug Fixes

- *(pre-commit-config.yaml)* Allow codespell to write changes by @Atticuszz

### 📚 Documentation

- *(mkdocs.yml)* Remove navigation.expand by @Atticuszz

### Bump

- Version 0.0.2 → 0.0.3 by @Atticuszz

## 0.0.2 - 2024-10-19

### 🐛 Bug Fixes

- Test commitizen by @Atticuszz
- *(CHANGELOG.md)* Test run commitizen by @Atticuszz

### 📚 Documentation

- Initial commit by @Atticuszz

### Bump

- Version 0.0.1 → 0.0.2 by @Atticuszz

<!-- generated by git-cliff -->

==> python_uv-0.0.32.tar.gz: python_uv-0.0.32/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

## 0.0.32 - 2024-10-27

### 🚀 Features

- Package python with uv by @Atticuszz

### 🐛 Bug Fixes

- *(CI)* Add PAT token to git cliff by @Atticuszz

### 🚜 Refactor

- Remove src/* -> src/python_uv/* as a package by @Atticuszz

### ⚙️ Miscellaneous Tasks

- Update vscode plugin python import config by @Atticuszz

## 0.0.30 - 2024-10-26

### ⚙️ Miscellaneous Tasks

- *(Merge)* Pull request #2 from Atticuszz:test-PR in #2 by @Atticuszz

## 0.0.29 - 2024-10-26

### ⚙️ Miscellaneous Tasks

- Remove commit_preprocessors on issue number by @Atticuszz

## 0.0.28 - 2024-10-26

### 🚀 Features

- *(CHANGELOG)* Add pr number and author name after commit message via set remote repo for git-cliff by @Atticuszz

## 0.0.27 - 2024-10-26

### 🐛 Bug Fixes

- Exclude hidden folder and file in pre-commit by @Atticuszz

### 📚 Documentation

- *(VCS)* Update CHANGELOG.md with link by @Atticuszz

### ⚙️ Miscellaneous Tasks

- *(VCS)* Add bump version shell by @Atticuszz
- Fix typo in README.md by @Atticuszz
- Clean config for git-cliff by @Atticuszz
- *(CHANGELOG)* Remove "[]" in version number by @Atticuszz
- *(CHANGELOG)* Remove "[]" in version number and filter duplicate commit message by @Atticuszz
- Remove duplicate config on git-cliff by @Atticuszz

## 0.0.23 - 2024-10-26

### 🐛 Bug Fixes

- *(CI)* Body->body_path context in release ci by @Atticuszz

## 0.0.22 - 2024-10-26

### 🐛 Bug Fixes

- *(CI)* Release without CHANGES.md by @Atticuszz

## 0.0.21 - 2024-10-26

### 🐛 Bug Fixes

- *(CI)* Release ci can not read latest changes by @Atticuszz

## 0.0.20 - 2024-10-26

### ⚙️ Miscellaneous Tasks

- Add notes for tool.bumpversion.allow_dirty=true by @Atticuszz

## 0.0.19 - 2024-10-25

### 🐛 Bug Fixes

- Pyproject.toml by @Atticuszz

## 0.0.18 - 2024-10-25

### 🐛 Bug Fixes

- Pyproject.toml version by @Atticuszz

## 0.0.17 - 2024-10-25

### 🐛 Bug Fixes

- Bumpverison files search name by @Atticuszz
- CHANGELOG.md bump replace result by @Atticuszz

## 0.0.16 - 2024-10-25

### 🐛 Bug Fixes

- Version in pyproject.toml by @Atticuszz

### ⚙️ Miscellaneous Tasks

- Add bump version to CHANGELOG.md by @Atticuszz

## 0.0.15 - 2024-10-25

### 🐛 Bug Fixes

- Bumpversion files by @Atticuszz

## 0.0.14 - 2024-10-25

### 🐛 Bug Fixes

- Bumpversion.files by @Atticuszz

## 0.0.13 - 2024-10-25

### ⚙️ Miscellaneous Tasks

- Add bumpversion files by @Atticuszz

## 0.0.12 - 2024-10-25

### 🐛 Bug Fixes

- Test bump by @Atticuszz

## 0.0.11 - 2024-10-25

### 🐛 Bug Fixes

- Test by @Atticuszz

## 0.0.10 - 2024-10-25

### 🐛 Bug Fixes

- *(vcs)* Remove changelog header by @Atticuszz
- *(CI)* Release-note is not total CHANGELOG.md by @Atticuszz
- *(CI)* Release only with tags branches by @Atticuszz
- *(CI)* Release on tags branches by @Atticuszz
- Test git-changelog by @Atticuszz
- *(dep)* Remove git-changelog by @Atticuszz

### ⚙️ Miscellaneous Tasks

- Add git-cliff by @Atticuszz
- Run pre-commit by @Atticuszz
- *(dep)* Update changelog by @Atticuszz
- Update pyproject.toml by @Atticuszz
- *(CI)* Remove release condition by @Atticuszz

### Bump

- *(CI)* Fix release body path file by @Atticuszz
- Fix ci if release conditions by @Atticuszz
- 0.0.9->0.0.10 by @Atticuszz

## 0.0.9 - 2024-10-23

### 🐛 Bug Fixes

- *(pyproject.toml)* Bug show by @Atticuszz
- *(pyproject.toml)* Add local dev commitizen by @Atticuszz

### 📚 Documentation

- Test  docs by @Atticuszz

### ⚡ Performance

- Test pre by @Atticuszz

### Bump

- Version 0.0.8 → 0.0.9 by @Atticuszz

## 0.0.8 - 2024-10-23

### 🐛 Bug Fixes

- *(.vscode)* Enable python package import plugin by @Atticuszz

### Bump

- Version 0.0.7 → 0.0.8 by @Atticuszz

## 0.0.7 - 2024-10-22

### 🐛 Bug Fixes

- *(main.yml)* Release condition is the commit message with bump: by @Atticuszz

### Bump

- Version 0.0.6 → 0.0.7 by @Atticuszz

## 0.0.6 - 2024-10-22

### 🐛 Bug Fixes

- *(main.ci)* Failed to get tag to release by @Atticuszz

### 📚 Documentation

- Update obsidian plugins by @Atticuszz

### Bump

- Version 0.0.5 → 0.0.6 by @Atticuszz

## 0.0.5 - 2024-10-20

### 🐛 Bug Fixes

- *(pyproject.toml)* Test fix by @Atticuszz
- *(pyproject.toml)* Add all change_type to changelog_pattern by @Atticuszz
- *(pyproject.toml)* Change_type_map by @Atticuszz
- Pyproject.toml by @Atticuszz

### 📚 Documentation

- *(mkdocs.yml)* Update site name and copyright by @Atticuszz

### Bump

- Version 0.0.4 → 0.0.5 by @Atticuszz

## 0.0.4 - 2024-10-19

### 🐛 Bug Fixes

- *(.obsidian)* Remove obsidian-git plugin by @Atticuszz

### 📚 Documentation

- *(docs/)* Remove git plugin of .obsidian and update all by @Atticuszz
- *(README.md)* Update by @Atticuszz

### 🎨 Styling

- *(.obsidian)* Pre-commit run by @Atticuszz

### ⚙️ Miscellaneous Tasks

- *(docs.yml,-main.yml)* 1. update ci uses as @main instead of @v_number, 2. add bump and release by @Atticuszz

### Bump

- Version 0.0.3 → 0.0.4 by @Atticuszz

## 0.0.3 - 2024-10-19

### 🐛 Bug Fixes

- *(pre-commit-config.yaml)* Allow codespell to write changes by @Atticuszz

### 📚 Documentation

- *(mkdocs.yml)* Remove navigation.expand by @Atticuszz

### Bump

- Version 0.0.2 → 0.0.3 by @Atticuszz

## 0.0.2 - 2024-10-19

### 🐛 Bug Fixes

- Test commitizen by @Atticuszz
- *(CHANGELOG.md)* Test run commitizen by @Atticuszz

### 📚 Documentation

- Initial commit by @Atticuszz

### Bump

- Version 0.0.1 → 0.0.2 by @Atticuszz

<!-- generated by git-cliff -->
